@@ -31,10 +31,12 @@ print.FielDHub <- function(x, n=10, ...){
   #---------------------------------------------------------------------
   # Parameters
   #---------------------------------------------------------------------
-  if (x$infoDesign$idDesign == 1) {
+  if (x$infoDesign$id_design == 1) {
     cat("Completely Randomized Design (CRD)", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -44,11 +46,13 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the CRD field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 2){
+  }else if (x$infoDesign$id_design == 2){
     cat("Randomized Complete Block Design (RCBD):", "\n\n")
     #-----------------------------------------------------------
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -58,10 +62,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the RCBD field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 3){
+  }else if (x$infoDesign$id_design == 3){
     cat("Latin Square Design:", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -71,10 +77,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the latin_square field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 4) {
+  }else if (x$infoDesign$id_design == 4) {
     cat("Full Factorial Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -84,10 +92,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the full_factorial field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 5) {
+  }else if (x$infoDesign$id_design == 5) {
     cat("Split Plot Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -97,10 +107,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the split_plot field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 6) {
+  }else if (x$infoDesign$id_design == 6) {
     cat("Split-Split Plot Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -110,10 +122,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the split_split_plot field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 7) {
+  }else if (x$infoDesign$id_design == 7) {
     cat("Strip Plot Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -123,10 +137,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the strip_plot field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 8) {
+  }else if (x$infoDesign$id_design == 8) {
     cat("Incomplete Blocks Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -136,10 +152,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the incomplete_blocks field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 9) {
+  }else if (x$infoDesign$id_design == 9) {
     cat("Row Column Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -149,10 +167,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the row_column field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 10) {
+  }else if (x$infoDesign$id_design == 10) {
     cat("Square Lattice Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -162,10 +182,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the square_lattice field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 11) {
+  }else if (x$infoDesign$id_design == 11) {
     cat("Rectangular Lattice Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -175,10 +197,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the rectangular_lattice field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 12) {
+  }else if (x$infoDesign$id_design == 12) {
     cat("Alpha Lattice Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -188,10 +212,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the alpha_lattice field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 13) {
+  }else if (x$infoDesign$id_design == 13) {
     cat("Partially Replicated Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -201,10 +227,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the partially_replicated field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 14) {
+  }else if (x$infoDesign$id_design == 14) {
     cat("Augmented Randomized Complete Block Design:", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -214,10 +242,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the RCBD_augmented field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 15) {
+  }else if (x$infoDesign$id_design == 15) {
     cat("Un-replicated Diagonal Arrangement Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -227,10 +257,12 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the diagonal_arrangement field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 16) {
+  }else if (x$infoDesign$id_design == 16) {
     cat("Un-replicated Optimized Arrangement Design", "\n\n")
     cat("Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
+    # str(x$infoDesign)
     #---------------------------------------------------------------------
     # Head
     #---------------------------------------------------------------------
@@ -240,7 +272,7 @@ print.FielDHub <- function(x, n=10, ...){
         "First observations of the data frame with the optimized_arrangement field book:",
         "\n")
     print(head(x$fieldBook, n=nhead_print, ...))
-  }else if (x$infoDesign$idDesign == 17) {
+  }else if (x$infoDesign$id_design == 17) {
     cat("Split families:", "\n\n")
     #---------------------------------------------------------------------
     # Head
@@ -311,7 +343,7 @@ summary.FielDHub <- function(object, ...) {
 #' @importFrom dplyr glimpse
 #' @export
 print.summary.FielDHub <- function(x, ...) {
-  if (x$infoDesign$idDesign == 1) {
+  if (x$infoDesign$id_design == 1) {
     cat("Completely Randomized Design (CRD):", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -320,7 +352,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("2. Structure of the data frame with the CRD field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 2) {
+  }else if (x$infoDesign$id_design == 2) {
     cat("Randomized Complete Block Design (RCBD):", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -338,7 +370,7 @@ print.summary.FielDHub <- function(x, ...) {
     cat("4. Structure of the data frame with the RCBD field book:", "\n\n")
     str(x$fieldBook)
     #---------------------------------------------------------------------
-  }else if (x$infoDesign$idDesign == 3) {
+  }else if (x$infoDesign$id_design == 3) {
     cat("Latin Square Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -356,7 +388,7 @@ print.summary.FielDHub <- function(x, ...) {
     cat("4. Structure of the data frame with the latin_square field book:", "\n\n")
     str(x$fieldBook)
     #---------------------------------------------------------------------
-  }else if (x$infoDesign$idDesign == 4) {
+  }else if (x$infoDesign$id_design == 4) {
     cat("Full Factorial Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -365,7 +397,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("2. Structure of the data frame with the full_factorial field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 5) {
+  }else if (x$infoDesign$id_design == 5) {
     cat("Split Plot Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -378,7 +410,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("3. Structure of the data frame with the split_plot field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 6) {
+  }else if (x$infoDesign$id_design == 6) {
     cat("Split-Split Plot Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -387,7 +419,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("2. Structure of the data frame with the split_split_plot field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 7) {
+  }else if (x$infoDesign$id_design == 7) {
     cat("Strip Plot Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -404,7 +436,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("4. Structure of the data frame with the strip_plot field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 8) {
+  }else if (x$infoDesign$id_design == 8) {
     cat("Incomplete Blocks Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -413,7 +445,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("2. Structure of the data frame with the incomplete_blocks field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 9) {
+  }else if (x$infoDesign$id_design == 9) {
     cat("Row Column Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -430,7 +462,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("4. Structure of the data frame with the row_column field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 10) {
+  }else if (x$infoDesign$id_design == 10) {
     cat("Square Lattice:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -439,7 +471,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("2. Structure of the data frame with the square_lattice field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 11) {
+  }else if (x$infoDesign$id_design == 11) {
     cat("Rectangular Lattice Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -448,7 +480,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("2. Structure of the data frame with the rectangular_lattice field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 12) {
+  }else if (x$infoDesign$id_design == 12) {
     cat("Alpha Lattice Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -457,7 +489,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("2. Structure of the data frame with the alpha_lattice field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 13) {
+  }else if (x$infoDesign$id_design == 13) {
     cat("Partially Replicated Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -477,7 +509,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("5. Structure of the data frame with the partially_replicated field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 14) {
+  } else if (x$infoDesign$id_design == 14) {
     cat("Augmented Randomized Complete Block Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -501,7 +533,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("6. Structure of the data frame with the RCBD_augmented field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 15) {
+  }else if (x$infoDesign$id_design == 15) {
     cat("Un-replicated Diagonal Arrangement Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
@@ -521,11 +553,12 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("5. Structure of the data frame with the diagonal_arrangement field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 16) {
+  }else if (x$infoDesign$id_design == 16) {
     cat("Un-replicated Optimized Arrangement Design:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Information on the design parameters:", "\n")
-    str(x$infoDesign)
+    len <- length(x$infoDesign)
+    str(x$infoDesign[1:(len-1)])
     cat("\n")
     #----------------------------------------------------------------------
     cat("2. Layout randomization:", "\n")
@@ -541,7 +574,7 @@ print.summary.FielDHub <- function(x, ...) {
     #---------------------------------------------------------------------
     cat("5. Structure of the data frame with the optimized_arrangement field book:", "\n\n")
     str(x$fieldBook)
-  }else if (x$infoDesign$idDesign == 17) {
+  }else if (x$infoDesign$id_design == 17) {
     cat("Split families:", "\n\n")
     #---------------------------------------------------------------------
     cat("1. Structure of the data frame with the summary of entries by location:", "\n\n")
@@ -551,3 +584,82 @@ print.summary.FielDHub <- function(x, ...) {
     str(x$data_locations)
   }
 }
+#-----------------------------------------------------------------------
+# Print plot
+#-----------------------------------------------------------------------
+#' @rdname print.fieldLayout
+#' @method print fieldLayout
+#' @title Print a \code{fieldLayout} plot object
+#' @usage \method{print}{fieldLayout}(x, ...)
+#' @aliases print.fieldLayout
+#' @description Prints a plot object of class \code{fieldLayout}.
+#' @return a plot object inheriting from class \code{fieldLayout}.
+#' @param x a plot object inheriting from class fieldLayout.
+#' @param ... unused, for extensibility.
+#' @author Didier Murillo [aut]
+#'
+#' @export
+print.fieldLayout <- function(x, ...) {
+  if (!missing(x)) {
+    if (is.null(x)) stop("x must be a fieldLayout object!")
+    if (!inherits(x,"fieldLayout")) {
+      stop("x must be a fieldLayout object!")
+    }
+    return(print(x$layout))
+  } else stop("x is missing!")
+}
+
+#-----------------------------------------------------------------------
+# Plot
+#-----------------------------------------------------------------------
+#' @rdname plot.FielDHub
+#' @method plot FielDHub
+#' @title Plot a \code{FielDHub} object
+#' @usage \method{plot}{FielDHub}(x, ...)
+#' @aliases plot.FielDHub
+#' @description Draw a field layout plot for a \code{FielDHub} object.
+#' @return 
+#' \itemize{
+#'   \item a plot object inheriting from class \code{fieldLayout}
+#'   \item \code{field_book} a data frame with the fieldbook that includes the coordinates ROW and COLUMN.
+#' } 
+#' @param x a object inheriting from class \code{FielDHub}
+#' @param ... further arguments passed to utility function \code{plot_layout()}.
+#' \itemize{
+#'   \item \code{layout} a integer. Options available depend on the 
+#'   type of design and its characteristics
+#'   \item \code{l} a integer to specify the location to plot.
+#'   \item \code{planter} it can be \code{serpentine} or \code{cartesian}.
+#'   \item \code{stacked} it can be \code{vertical} or \code{horizontal} stacked layout.
+#' } 
+#' @author Didier Murillo [aut]
+#' @examples
+#' \dontrun{
+#' # Example 1: Plot a RCBD design with 24 treatments and 3 reps.
+#' s <- RCBD(t = 24, reps = 3, plotNumber = 101, seed = 12)
+#' plot(s)
+#' }
+#'
+#' @export
+plot.FielDHub <- function(x, ...) {
+  if (!missing(x)) {
+    if (is.null(x)) stop("x must be a FielDHub object!")
+    if (!inherits(x,"FielDHub")) {
+      stop("x is not a FielDHub class")
+    }
+    p <- plot_layout(x = x, ...)
+    if (is.null(p)) {
+      img <- ggplot2::ggplot() + ggplot2::theme_minimal()
+      class(img) <- "fieldLayout"
+      print(x = img)
+    } else {
+      out <- list(
+        field_book = p$allSitesFieldbook,
+        layout = p$out_layout
+      )
+      class(out) <- "fieldLayout"
+      print(x = out)
+      return(invisible(list(field_book = out$field_book)))
+    }
+  } else stop("x is missing!")
+}
\ No newline at end of file
